local browser=cond(c(os)=="Unix","mozilla","explorer")
local gho=cond(c(os)=="Unix","gs","gswin32")
capture mkdir htm
capture mkdir tables
capture mkdir figures
use brfeed.dta
/* for each variable a table of frequency and a histogram is generated*/
foreach var of varlist pos natio edu brfeed{
	preserve
	local title:variable label `var'
	xcontract `var',nores
	qui sum _freq
	qui gen byte modal=(_freq==r(max))
	gen perc=string(_perc,"%3.1f")+"%"
	gen freq=string(_freq)
	/* in the table the modal values are put in boldface*/
	foreach desc in freq perc{
		replace `desc'="<b>"+ `desc'+" </b>" if modal==1
		}
	listtex `var' freq perc using tables/tab_`var'.htm,rstyle(html) headlines("<table align=center width=50%>" "<tr><th  colspan="3" align=center>`title'</th></tr> " "<tr><td> </td><td> Frequency </td><td>  Percentage  </td></tr>   ")  footlines(" </table>") replace
	restore
	/* the graphic is temporarily exported to eps, then translated into high-resolution png via ghostscript*/
	qui sum `var'
	local min=r(min)
	local max=r(max)
	hist `var', discrete width(.5)  ylabel(`min'(1)`max',valuelabel angle(hor)) xtitle("") freq ytitle("") graphregion(color(blue*.4)) bcolor(blue) hor
	tempfile graph
// 	graph export `graph'.eps,as(eps) replace
// 	winexec `gho' -q -dEPSCrop -dNOPROMPT -dBATCH -dNOPAUSE  -sDEVICE=png16m -r200 -dGraphicsAlphaBits=4 -sOutputFile=figures/graph_`var'.png `graph'.eps
	graph export figures/graph_`var'.png,replace 
	/* the htm file calling the image generated*/
	tempname tabfig
	file open `tabfig' using figures/tabfig_`var'.htm,write replace
	file write `tabfig' `"<table align=center width=90%>"' _n
	file write `tabfig' `"<tr><th>`title'</th></tr>"' _n
	file write `tabfig' `"<tr>"' _n
	file write `tabfig' `"<td valign="top">"' _n
	file write `tabfig' `"<img src="graph_`var'.png" width="90%" border="0" align="left" valign="top">"' _n
 
	file write `tabfig' `"</td>"' _n
	file write `tabfig' `"</tr>"' _n
	file write `tabfig' `"</table>"' _n
	file close `tabfig'
	}
/* the main document is generated */
cd htm
tempname main
file open `main' using main_brfeed.htm,write replace
file write `main' `"<!--File automatically generated by Stata-->"' _n
file write `main' `"<h2 align=center>Survey on child care behaviours<h2>"' _n
file write `main' `"<br><br>"' _n
file write `main' `"<table align=center width=30%>"' _n
file write `main' `"<tr><td><b>Variable</b></td><td><b>Table</b></td><td><b>Graph</b></td><tr>"' _n
foreach var of varlist pos natio edu brfeed{
					local title:variable label `var'
					file write `main' `"<tr><td>`title'</td><td><a Href='../tables/tab_`var'.htm'>[X]<a></td><td><a Href='../figures/tabfig_`var'.htm'>[X]<a></td><tr>"' _n
							}
file write `main' `"</table>"' _n

/* the main document is opened via a browser*/
winexec `browser' main_brfeed.htm
